ipmcset -d upgrade -v /tmp/rootfs_openUBMC.hpm 
ls /tmp/
/opt/debug/busybox telnet 192.168.2.100 23
date
ipmcset -t certificate -d import -v /tmp/cert.p12 1 123456
ls
ipmcget -d v
ipmicmd -k "0f 00 06 01" smi 0
tail -f /var/log/app.log
cd /
cd /
ls
cd var/
ls
cd log/
ll
ls
cd log/
cd log
sudo cd log
cd ~
cat /etc/os-release
tail -f /var/log/app.log
cat /var/log/app.log
ls /var/log/app.log
sudo ls /var/log/app.log
cd var
cd /
cd var/
ls
ca log
cd log
ll
lsv-la
ls -la
su root
cd tmp/
ls
cd ..
ls
cd log/
chmod 777 log/
busctl --user list
busctl --user tree bmc.kepler.ipmi_core
busctl --user introspect bmc.kepler.ipmi_core /bmc/kepler/IpmiCore
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 11 0x2E 0 0x33 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 12 0x2E 0 0x33 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 12 0x2E 0 0x32 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 11 0x2E 0 0x33 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 11 0x2E 0 0x32 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 11 0x2E 0 0x33 0
lsobj
mdbctl lsobj
mdbctl lsprop ThresholdSensor_FIOVCC5V0
mdbctl lsprop Scanner_FIO5V0
mdbctl lsobj
cd /etc/systemd/system/
ls
ll
cp hardware.service hardware_bak.service 
chmod +777 hardware.service 
chmod + * hardware.service 
vim hardware.service 
vi hardware.service 
cat hardware.service 
ll
ls -la /etc/systemd/system
uname
uname -a
whoami 
cd /root/
sudo
touch a
cd
ls
touch a
ls
rm a 
ls
cd /
ls -la
df -h
lsblk
cd /etc/
mount
cd sys
cd ..
cd sys/
ls
touch a
ls
cd ..
ls
whoim
whoami
source /etc/profile
busctl --user list
busctl --user tree bmc.kepler.ipmi_core
busctl --user introspect /bmc/kepler/IpmiCmds/04/21/GetDeviceSDR
busctl --user introspect  bmc.kepler.ipmi_core /bmc/kepler/IpmiCmds/04/21/GetDeviceSDR
mdbctl lsprop ""
mdbctl lsprop 
busctl --user tree
busctl --user introspect bmc.kepler.bios /bmc/kepler/IpmiCmds/06/59/GetChannelInfo
cd /var/log/
mdbctl lsprop ThresholdSensor_SlotID_0101
busctl --user list
busctl --user tree bmc.kepler.ipmi_core
busctl --user introspect bmc.kepler.ipmi_core /bmc/kepler/IpmiCmds/04/21/GetDeviceSDR
mdbctl lsprop ThresholdSensor_SlotID_0101
mdbctl lsprop ThresholdSensor_SlotID
mdbctl lsprop
mdbctl lsprop list
mdbctl list
mdbctl -h
mdbctl h
lsobj Scanner_FIBBERTemp
% lsobj
% lsclass
busctl tree | grep Scanner_FIBBERTemp
mdbctl lsprop Scanner_FIBBERTemp
mdbctl
ls
cd /
ls
cd home/
ls
cd Administrator/
ls'
ls
ll
ls
cd /opt/
ls
cd debug/
ls
cd ../
cd bmc/
ls
cd apps/
ls
cd /dump_info/AppDump/hwproxy/
find / -type d -name "hwproxy" 2>/dev/null
cd /opt/bmc/apps/hwproxy
mdbctl
busctl --user monitor bmc.kepler.Scanner Scanner_BMC3V3_0101
busctl help
busctl --user tree bmc.kepler.Scanner
busctl --user list
busctl --user tree bmc.kepler.sensor
busctl --user tree bmc.kepler.Scanner
busctl --user monitor bmc.kepler.Scanner Scanner_BMC3V3_0101
mdbctl
mdbctl 
busctl --user get-property bmc.kepler.hwproxy /bmc/kepler/Scanner/Scanner_BMC3V3_0101 bmc.kepler.Scanner Value
ipmcset
ipmcset -d ipmiraw -v &quot;<0x06> <0x01> [0]&quot
ipmcset -d ipmiraw -v &quot;0x06 0x01 0&quot
ipmcset -d ipmiraw -v "0x06 0x01 0"
ipmcget info
ipmcget systemcom
ipmcget -d systemcom
ipmcget -d time
ipmcget -d powerstate
ipmcget -d bootdevice
ipmcget -d userlist
ipmcget -t certificate
ipmcget -t sensor
ipmcget -d list
ipmcget -t sensor -d list
ipmcset -t ipmb -d ipmiraw -v “”“0 "    
ipmcset -t ipmb -d ipmiraw -v "0x86 0x06 0x01"
source /etc/profile
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 1 0x06 0 0x01 0x00
ipmcset -t ipmb -d ipmiraw -v "0x86 0x06 0x01"
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 1 0x06 0 0x01 0x00
ipmcsetbusctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 1 0x06 0 0x01 0x00
ipmcset -t ipmb -d ipmiraw -v "0x86 0x06 0x01"
ipmcsetbusctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 1 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 1 0x06 0 0x01 0x00
cd ~
ls
cd /
ls
cd home/
ls
ls -al
cd Administrator/
ls
cd ../
ls
cd /
ls
cd tmp/
ls
./devmemx -r 0x08745034 0x08745050
ls -al
chmod +777 devmemx 
chmod 777 devmemx 
ls
ls -al
./devmemx -r 0x08745034 0x08745050
mv devmemx /data/trust/home/
cd /var/log/
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 5 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 5 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 5 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 5 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
tail -f /var/log/app
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 5 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 5 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 5 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x2E 0 0x11 0x00
ipmicmd -k "0f 00 06 01" smi 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x07
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x2E 0 0x11 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x2E 0 0x11 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x2E 0 0x11 0x00
tail -f /var/log/app.log
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
ipmicmd -k "0f 00 06 01" smi 0
busctl --user tree bmc.kepler.ming
busctl --user tree bmc.kepler.ming_app
ipmcget 
ipmcget -d version
ipmcget -d v
ipmcget -d 
ipmcget -d ethport
ipmcget -d ipinfo
ipmcget -d operatelog
ipmcget -d 
ipmcget -d psuinfo
ipmcget -d userlist
ipmcget -d version
i2cdetect -y 2
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 134 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 67 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 134 6 0x2E 0 0x11 ""
busctl --user tree bmc.kepler.appIpmb
journalctl -u appIpmb --no-pager -n 50
busctl --user tree bmc.kepler.ipmi_core
busctl --user tree bmc.kepler.app_test
budctl --user tree bmc.kepler.appIpmb
budctl --user tree bmc.kepler.app_test
busctl --user tree bmc.kepler.appIpmb
journalctl -u appIpmb --no-pager -n 100
busctl --user tree bmc.kepler.appIpmb
busctl --user call bmc.kepler.appIpmb /bmc/kepler/appIpmb/MicroComponent bmc.kepler.MicroComponent HealthCheck a{ss} 0
busctl get-property bmc.kepler.appIpmbTarget /bmc/kepler/Systems/1/IpmiDevices/powerboard  bmc.kepler.Inventory.Hardware FirmwareVersion
busctl --user tree
busctl --user tree bmc.kepler.appIpmbTarget
  busctl --user get-property bmc.kepler.appIpmbTarget /bmc/kepler/Systems/1/IpmiDevices/powerboard  bmc.kepler.Inventory.Hardware FirmwareVersion
  busctl --user get-property bmc.kepler.appIpmbTarget  /bmc/kepler/Systems/1/IpmiDevices/powerboard  bmc.kepler.Inventory.Hardware FirmwareVersion
  busctl call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore \
Request a{ss}yyyyyay 0 1 6 6 0 1 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore  Request a{ss}yyyyyay 0 1 6 6 0 1 0
busctl --user get-property bmc.kepler.appIpmbTarget   /bmc/kepler/Systems/1/IpmiDevices/powerboard  bmc.kepler.Inventory.Hardware FirmwareVersion
busctl --user get-property bmc.kepler.appIpmbTarget  /bmc/kepler/Systems/1/IpmiDevices/powerboard   bmc.kepler.Systems.Board RunningStatus
grep -i appIpmbTarget /var/log/messages | tail 
grep -i appIpmbTarget /var/log/app.log | tail 
ipmcget -d v
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore \
      Request a{ss}yyyyyay 0 1 6 0x04 0 0x21 0x00 0x00 0x00 0x00 0x00 0x40
ipmcget -d v
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x21 0x00 0x00 0x00 0x00 0x00 0x40
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x21 0x06 0x00 0x00 0x00 0x00 0x00 0x40
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x21 0x00 0x00 0x00 0x00 0x00 0x40
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x21 0x06 0x00 0x00 0x00 0x00 0x00 0x40
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x2D 0x01 0x01
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x06 0 0x01 0x00
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x2D 0x01 0x01
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x2D 0x01 0x01
busctl --user call bmc.kepler.ipmi_core /bmc/kepler/IpmiCore bmc.kepler.IpmiCore Request a{ss}yyyyyay 0 1 6 0x04 0 0x21 0x06 0x00 0x00 0x00 0x00 0x00 0x40
